django_analyses.filters package — django_analyses 0.0.3 documentation

# django_analyses.filters package

## Subpackages

- django_analyses.filters.input package
  - Submodules
  - django_analyses.filters.input.input module
  - django_analyses.filters.input.input_definition module
  - Module contents
- django_analyses.filters.output package
  - Submodules
  - django_analyses.filters.output.output module
  - django_analyses.filters.output.output_definition module
  - Module contents
- django_analyses.filters.pipeline package
  - Submodules
  - django_analyses.filters.pipeline.node module
  - django_analyses.filters.pipeline.pipe module
  - django_analyses.filters.pipeline.pipeline module
  - Module contents

## Submodules

## django_analyses.filters.analysis module

class `django_analyses.filters.analysis.` `AnalysisFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Analysis` model.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'title', 'description', 'created')
    `model`

      alias of `django_analyses.models.analysis.Analysis`

  `base_filters` = {'created': <django_filters.filters.DateTimeFromToRangeFilter object>, 'description': <django_filters.filters.LookupChoiceFilter object>, 'id': <django_filters.filters.NumberFilter object>, 'title': <django_filters.filters.LookupChoiceFilter object>}
  `declared_filters` = {'created': <django_filters.filters.DateTimeFromToRangeFilter object>, 'description': <django_filters.filters.LookupChoiceFilter object>, 'title': <django_filters.filters.LookupChoiceFilter object>}

## django_analyses.filters.category module

class `django_analyses.filters.category.` `CategoryFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Category` model.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'title', 'description', 'parent', 'is_root')
    `model`

      alias of `django_analyses.models.category.Category`

  `base_filters` = {'description': <django_filters.filters.LookupChoiceFilter object>, 'id': <django_filters.filters.NumberFilter object>, 'is_root': <django_filters.rest_framework.filters.BooleanFilter object>, 'parent': <django_filters.filters.CharFilter object>, 'title': <django_filters.filters.LookupChoiceFilter object>}
  `declared_filters` = {'description': <django_filters.filters.LookupChoiceFilter object>, 'is_root': <django_filters.rest_framework.filters.BooleanFilter object>, 'parent': <django_filters.filters.CharFilter object>, 'title': <django_filters.filters.LookupChoiceFilter object>}
  `filter_is_root`(queryset, name: str, value: bool)

## Module contents